"use client";

import { TCountry } from "@/types/type";
import { CountriesList } from "../ui/CountriesList/CountriesList";
import { useState } from "react";
import { CountriesInfo } from "../ui/CountriesInfo/CountriesInfo";
import { baseUrl } from "@/helpers/api";

type Props = {
    countryList: TCountry[];
};

export const HomePage = ({ countryList }: Props) => {
    const [country, setCountry] = useState<TCountry | null>(null);
    const [bCountries, setBCountries] = useState<TCountry[]>([]);

    const handleSelectCountry = (cca2: string) => {
        const newCountry = countryList.find((c) => c.cca2 === cca2);
        if (!newCountry) {
            console.log("Нет такой страны");
            return;
        }
        setCountry(newCountry);
        if (!newCountry.borders) {
            setBCountries([]);
            return;
        }

        fetchBorderedCountry(newCountry.borders);
    };

    const fetchBorderedCountry = async (arr: string[]) => {
        const responses = await Promise.all(
            arr.map((code) => fetch(`${baseUrl}/alpha/${code}`).then((res) => res.json())),
        );
        setBCountries(responses.flat());
    };

    return (
        <div>
            <CountriesList countryList={countryList} onSelect={handleSelectCountry} />
            <CountriesInfo country={country} borderCountries={bCountries} />
        </div>
    );
};
