import { TCountry } from "@/types/types";
import Image from "next/image";
import styles from "./CountryInfo.module.css";

type Props = {
    country: TCountry | null;
    borders: TCountry[];
};

export const CountryInfo = ({ country, borders }: Props) => {
    if (!country) return <div className={styles.preloader}>ChooseCountry</div>;

    const imageUrl = country.flags.png || "/defaultFlag.pnp";
    const imageAlt = country.flags.alt || country.name.common;
    return (
        <div className={styles.wrapper}>
            <div className={styles.header}>
                <h2>Country: {country.name.common}</h2>
                <Image src={imageUrl} alt={imageAlt} width={300} height={150} />
            </div>
            <ul>
                <li>
                    <b>capital:</b> {country.capital}
                </li>
                <li>
                    <b>area:</b> {country.area}
                </li>
                <li>
                    <b>population:</b> {country.population}
                </li>
            </ul>
            <ul>
                <li>
                    <b>Neighbor:</b>
                </li>
                {borders.filter(Boolean).map((borderCountry, index) => (
                    <li key={index}>{borderCountry?.name?.common}</li>
                ))}
            </ul>
        </div>
    );
};
